==> xmlworker-1.0.0-sources.jar: com/itextpdf/tool/xml/pipeline/ctx/WorkerContextImpl.java <==
/*
 * $Id: WorkerContextImpl.java 160 2011-06-07 09:34:57Z redlab_b $
 *
 * This file is part of the iText (R) project.
 * Copyright (c) 1998-2011 1T3XT BVBA
 * Authors: Balder Van Camp, Emiel Ackermann, et al.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation with the addition of the
 * following permission added to Section 15 as permitted in Section 7(a):
 * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY 1T3XT,
 * 1T3XT DISCLAIMS THE WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 * You should have received a copy of the GNU Affero General Public License
 * along with this program; if not, see http://www.gnu.org/licenses or write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA, 02110-1301 USA, or download the license from the following URL:
 * http://itextpdf.com/terms-of-use/
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License,
 * a covered work must retain the producer line in every PDF that is created
 * or manipulated using iText.
 *
 * You can be released from the requirements of the license by purchasing
 * a commercial license. Buying such a license is mandatory as soon as you
 * develop commercial activities involving the iText software without
 * disclosing the source code of your own applications.
 * These activities include: offering paid services to customers as an ASP,
 * serving PDFs on the fly in a web application, shipping iText with a closed
 * source product.
 *
 * For more information, please contact iText Software Corp. at this
 * address: sales@itextpdf.com
 */
package com.itextpdf.tool.xml.pipeline.ctx;

import com.itextpdf.tool.xml.CustomContext;
import com.itextpdf.tool.xml.NoCustomContextException;
import com.itextpdf.tool.xml.WorkerContext;
import com.itextpdf.tool.xml.exceptions.NotImplementedException;

/**
 * The global WorkerContext, a storage for CustomContexts. It extends
 * {@link MapContext} but overrides the MapContext methods to throw
 * {@link NotImplementedException}.
 *
 * @author redlab_b
 *
 */
public class WorkerContextImpl implements WorkerContext {

	private final MapContext mc;

	/**
	 *
	 */
	public WorkerContextImpl() {
		this.mc = new MapContext();
	}
	/* (non-Javadoc)
	 * @see com.itextpdf.tool.xml.pipeline.WorkerContext#get(java.lang.Class)
	 */
	public CustomContext get(final String klass) throws NoCustomContextException {
		 Object c = mc.get(klass);
		 if (c != null) {
			 return (CustomContext) c;
		 }
		 throw new NoCustomContextException();
	}
	/**
	 * Convenience method.
	 * @param key the key to store the CustomContext for.
	 * @param context the CustomContext to store.
	 */
	public void add(final String key, final CustomContext context) {
		mc.put(key, context);
	}


}

==> xmlworker-1.1.1-sources.jar: com/itextpdf/tool/xml/pipeline/ctx/WorkerContextImpl.java <==
/*
 * $Id: WorkerContextImpl.java 188 2011-07-05 12:33:20Z redlab_b $
 *
 * This file is part of the iText (R) project.
 * Copyright (c) 1998-2011 1T3XT BVBA
 * Authors: Balder Van Camp, Emiel Ackermann, et al.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation with the addition of the
 * following permission added to Section 15 as permitted in Section 7(a):
 * FOR ANY PART OF THE COVERED WORK IN WHICH THE COPYRIGHT IS OWNED BY 1T3XT,
 * 1T3XT DISCLAIMS THE WARRANTY OF NON INFRINGEMENT OF THIRD PARTY RIGHTS.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Affero General Public License for more details.
 * You should have received a copy of the GNU Affero General Public License
 * along with this program; if not, see http://www.gnu.org/licenses or write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA, 02110-1301 USA, or download the license from the following URL:
 * http://itextpdf.com/terms-of-use/
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU Affero General Public License.
 *
 * In accordance with Section 7(b) of the GNU Affero General Public License,
 * a covered work must retain the producer line in every PDF that is created
 * or manipulated using iText.
 *
 * You can be released from the requirements of the license by purchasing
 * a commercial license. Buying such a license is mandatory as soon as you
 * develop commercial activities involving the iText software without
 * disclosing the source code of your own applications.
 * These activities include: offering paid services to customers as an ASP,
 * serving PDFs on the fly in a web application, shipping iText with a closed
 * source product.
 *
 * For more information, please contact iText Software Corp. at this
 * address: sales@itextpdf.com
 */
package com.itextpdf.tool.xml.pipeline.ctx;

import com.itextpdf.tool.xml.CustomContext;
import com.itextpdf.tool.xml.NoCustomContextException;
import com.itextpdf.tool.xml.Tag;
import com.itextpdf.tool.xml.WorkerContext;
import com.itextpdf.tool.xml.exceptions.NotImplementedException;

/**
 * The global WorkerContext, a storage for CustomContexts. It extends
 * {@link MapContext} but overrides the MapContext methods to throw
 * {@link NotImplementedException}.
 *
 * @author redlab_b
 *
 */
public class WorkerContextImpl implements WorkerContext {

	private final MapContext mc;
	private Tag tag;

	/**
	 *
	 */
	public WorkerContextImpl() {
		this.mc = new MapContext();
	}
	/* (non-Javadoc)
	 * @see com.itextpdf.tool.xml.pipeline.WorkerContext#get(java.lang.Class)
	 */
	public CustomContext get(final String klass) throws NoCustomContextException {
		 Object c = mc.get(klass);
		 if (c != null) {
			 return (CustomContext) c;
		 }
		 throw new NoCustomContextException();
	}
	/**
	 * Convenience method.
	 * @param key the key to store the CustomContext for.
	 * @param context the CustomContext to store.
	 */
	public void put(final String key, final CustomContext context) {
		mc.put(key, context);
	}
	/* (non-Javadoc)
	 * @see com.itextpdf.tool.xml.WorkerContext#setCurrentTag()
	 */
	public void setCurrentTag(final Tag t) {
		this.tag = t;

	}
	/* (non-Javadoc)
	 * @see com.itextpdf.tool.xml.WorkerContext#getCurrentTag()
	 */
	public Tag getCurrentTag() {
		return tag;
	}


}
